lilypondfiletools.DateTimeToken
===============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken

.. autoclass:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.DateTimeToken.DateTimeToken.DateTimeToken.__repr__
   :noindex:
